==> snipe-it-5.1.8.zip: snipe-it-5.1.8/resources/lang/en-ID/general.php <==
<?php

    return [
    'accessories'			=> 'Aksesoris',
    'activated'			    => 'Diaktifkan',
    'accessory'				=> 'Aksesoris',
    'accessory_report'		=> 'Laporan Aksesori',
    'action'                => 'Langkah',
    'activity_report'		=> 'Laporan Aktifitas',
    'address'				=> 'Alamat',
    'admin'					=> 'Admin',
    'administrator'			=> 'Administrator',
    'add_seats'             => 'Seat ditambahkan',
    'all_assets'			=> 'Semua aset',
    'all'       			=> 'Semua',
    'archived'              => 'Diarsipkan',
    'asset_models'			=> 'Model aset',
    'asset_model'			=> 'Model',
    'asset'					=> 'Aset',
    'asset_report'          => 'Laporan aset',
    'asset_tag'				=> 'Penanda aset',
    'assets_available'		=> 'aset tersedia',
    'audit'				    => 'Audit',
    'audit_report'			=> 'Audit Log',
    'assets'				=> 'Aset',
    'avatar_delete'         => 'Hapus Avatar',
    'avatar_upload'         => 'Unggah Avatar',
    'back'      			=> 'Kembali',
    'bad_data'      		=> 'Tidak ada yang ditemukan. Mungkinkah data buruk?',
    'bulkaudit'             => 'Bulk Audit',
    'bulkaudit_status'      => 'Status Audit',
    'bulk_checkout'  		=> 'Periksa Bulk',
    'bystatus'              => 'by Status',
    'cancel'  				=> 'Batal',
    'categories'			=> 'Kategori',
    'category'				=> 'Kategori',
    'change' 		        => 'Masuk/keluar',
    'changeemail'  			=> 'Ubah alamat surel',
    'changepassword'  		=> 'Ubah kata sandi',
    'checkin'  				=> 'Mendaftar',
    'checkin_from'  		=> 'Checkin dari',
    'checkout'  			=> 'Checkout',
    'checkouts_count'       => 'Keluar',
    'checkins_count'        => 'Masuk',
    'user_requests_count'   => 'Permintaan',
    'city'  				=> 'Kota',
	'click_here'			=> 'Klik disini',
    'clear_selection'		=> 'Hapus yang dipilih',
    'companies'			    => 'Perusahaan',
    'company'				=> 'Perusahaan',
    'component'			    => 'Komponen',
    'components'			=> 'Komponen',
	'complete'				=> 'Lengkap',
    'consumable'			=> 'Dapat dikonsumsi',
    'consumables'			=> 'Dapat dikonsumsi',
    'country'  				=> 'Negara',
    'create'				=> 'Buat baru',
    'created'               => 'Item telah dibuat',
    'created_asset'			=> 'buat aset',
    'created_at' 			=> 'Dibuat di',
    'record_created' 		=> 'Record Created',
    'updated_at' 			=> 'Diperbarui pada',
    'currency'  			=> 'IDR', // this is deprecated
    'current'  				=> 'Saat ini',
    'custom_report'         => 'Laporan aset kostum',
    'dashboard'				=> 'Dashboard',
    'days'      			=> 'hari',
    'days_to_next_audit'    => 'Hari untuk audit selanjutnya',
    'date'					=> 'Tanggal',
    'debug_warning'         => 'Peringatan!',
    'debug_warning_text'    => 'Aplikasi ini berjalan dalam mode produksi dengan debugging diaktifkan. Hal ini dapat mengekspos data sensitif jika aplikasi Anda dapat diakses oleh dunia luar. Nonaktifkan mode debug dengan menetapkan nilai <code>APP_DEBUG</code> value in your <code>.env</code> file to <code>false</code>.',
    'delete'  				=> 'Hapus',
    'delete_confirm'  		=> 'Apa Anda yakin untuk menghapus :item?',
    'deleted'  				=> 'Dihapus',
    'delete_seats'  		=> 'Tempat dihapus',
    'departments'           => 'Departemen',
    'department'           => 'Departemen',
    'deployed'				=> 'Diterapkan',
    'depreciation_report'	=> 'Laporan Penurunan',
    'details'               => 'Detail',
    'download'				=> 'Unduh',
    'download_all'				=> 'Download All',
    'depreciation'			=> 'Penurunan nilai',
    'editprofile'  			=> 'Sunting profil anda',
    'eol'					=> 'EOL',
    'email_domain'			=> 'Email Domain',
    'email_format'			=> 'Format Surel',
    'email_domain_help'		=> 'Ini digunakan untuk menghasilkan alamat surel ketika saat mengimpor',
    'filastname_format'			=> 'Nama Depan Nama Belakang (jane.smith@example.com)',
    'firstname_lastname_format'	=> 'Nama Depan Nama Belakang (jane.smith@example.com)',
    'firstname_lastname_underscore_format' => 'Nama Depan Nama Belakang (jane.smith@example.com)',
    'lastnamefirstinitial_format' =>  'Nama Depan First Initial (smithj@example.com)',
    'firstintial_dot_lastname_format' => 'First Initial Last Name (j.smith@example.com)',
    'first'					=> 'Pertama',
    'firstnamelastname'     => 'First Name Last Name (janesmith@example.com)',
    'lastname_firstinitial' => 'Last Name First Initial (smith_j@example.com)',
    'firstinitial.lastname' => 'First Initial Last Name (j.smith@example.com)',
    'firstnamelastinitial'  => 'First Name Last Initial (janes@example.com)',
    'first_name'			=> 'Nama Pertama',
    'first_name_format'		=> 'Nama Depan (jane@example.com)',
    'files'                 => 'Berkas',
    'file_name'				=> 'Berkas',
    'file_type'             => 'File Type',
    'file_uploads'			=> 'Unggah berkas',
    'generate'				=> 'Hasilkan',
     'github_markdown'      => 'Bidang ini mengizinkan penggunaan <a href="https://help.github.com/articles/github-flavored-markdown/">kode markup milik Github</a>.',
    'groups'				=> 'Kelompok',
    'gravatar_email'        => 'Alamat Email Gravatar',
    'history'  			    => 'Riwayat',
    'history_for'  			=> 'Riwayat untuk',
    'id'  					=> 'ID',
    'image'                 => 'Gambar',
    'image_delete'         	=> 'Hapus Gambar',
    'image_upload'         	=> 'Unggah Gambar',
    'image_filetypes_help'  => 'Accepted filetypes are jpg, webp, png, gif, and svg. Max upload size allowed is :size.',
    'import'         	    => 'Impor',
    'importing'         	=> 'Importing',
    'importing_help'        => 'You can import assets, accessories, licenses, components, consumables, and users via CSV file. <br><br>The CSV should be comma-delimited and formatted with headers that match the ones in the <a href="https://snipe-it.readme.io/docs/importing" target="_new">sample CSVs in the documentation</a>.',
    'import-history'        => 'Riwayat Impor',
    'asset_maintenance'        => 'Pemeliharaan Aset',
    'asset_maintenance_report' => 'Laporan Pemeliharaan Aset',
    'asset_maintenances'       => 'Pemeliharaan Aset',
    'item'  				=> 'Item',
    'insufficient_permissions' => 'Tidak ada hak akses!',
    'kits'       			=> 'Predefined Kits',
    'language'				=> 'Bahasa',
    'last'					=> 'Terakhir',
    'last_login'            => 'Login terakhir',
    'last_name'             => 'Nama Belakang',
    'license'				=> 'Lisensi',
    'license_report'        => 'Laporan Lisensi',
    'licenses_available'	=> 'lisensi yang tersedia',
    'licenses'				=> 'Lisensi',
    'list_all'				=> 'Tampilkan semua',
    'loading'				=> 'Memuat',
    'lock_passwords'        => 'This field value will not be saved in a demo installation.',
    'feature_disabled'      => 'Fitur ini telah dinonaktifkan untuk instalasi demo.',
    'location'              => 'Lokasi',
    'locations'				=> 'Lokasi',
    'logo_size'				=> 'Square logos look best with Logo + Text. Logo maximum display size is 50px high x 500px wide.  ',
    'logout'				=> 'Keluar',
    'lookup_by_tag'     => 'Mencari berdasarkan tag aset',
    'maintenances'          => 'Pemeliharaan',
    'manufacturer'			=> 'Pabrikan',
    'manufacturers'			=> 'Pabrikan',
    'markdown'				=> 'Bidang ini mengizinkan penggunaan <a href="https://help.github.com/articles/github-flavored-markdown/">kode markup milik Github</a>.',
    'min_amt'				=> 'Jml Min.',
    'min_amt_help'	=> 'Jumlah item minimal yang tersedia sebelum pemberitahuan diaktifkan.',
    'model_no'				=> 'No. Model',
    'months'				=> 'bulan',
    'moreinfo'				=> 'Info Lengkap',
    'name'					=> 'Nama',
    'next'					=> 'Selanjutnya',
    'next_audit_date'		=> 'Tanggal Audit berikutnya',
    'last_audit'		    => 'Audit Terakhir',
    'new'					=> 'baru!',
    'no_depreciation'		=> 'Tidak ada penyusutan',
    'no_results'			=> 'Tidak ada Hasil.',
    'no'  					=> 'Tidak',
    'notes'  				=> 'Catatan',
    'order_number'          => 'Nomor Pemesanan',
    'page_menu'				=> 'Menampilkan item _MENU_',
    'pagination_info'		=> 'Menampilkan item _START_ to _END_ of _TOTAL_',
    'pending'				=> 'Tertunda',
    'people'				=> 'Orang',
    'per_page'				=> 'Hasil per Halaman',
    'previous'				=> 'Sebelumnya',
    'processing'			=> 'Memproses',
    'profile'				=> 'Profil anda',
    'purchase_cost'                              => 'Harga pembelian',
    'purchase_date'         => 'Tanggal Pembelian',
    'qty'		            => 'JML',
    'quantity'		        => 'Jumlah',
    'ready_to_deploy'		=> 'Siap digunakan',
    'recent_activity'		=> 'Aktifitas tebaru',
    'remove_company'        => 'Hapus Asosiasi Perusahaan',
    'reports'				=> 'Laporan',
    'restored'				=> 'dikembalikan',
    'requested'				=> 'Diminta',
    'request_canceled'      => 'Permintaan dibatalkan',
    'save'  				=> 'Simpan',
    'select'				=> 'Pilih',
    'search'				=> 'Cari',
    'select_category'       => 'Pilih kategori',
    'select_department'       => 'Pilih Departemen',
    'select_depreciation'	=> 'Pilih Jenis Penyusutan',
    'select_location'		=> 'Pilih lokasi',
    'select_manufacturer'	=> 'Pilih Produsen',
    'select_model'			=> 'Pilih sebuah model',
    'select_supplier'		=> 'Pilih pabrikan',
    'select_user'			=> 'Pilih pengguna',
    'select_date'			=> 'Pilih tanggal (YYYY-MM-DD)',
    'select_statuslabel'	=> 'Pilih status',
    'select_company'    	=> 'Pilih perusahaan',
    'select_asset'    		=> 'Pilih aset',
    'settings'				=> 'Pengaturan',
    'show_deleted'  		=> 'Tampilkan yang Dihapus',
    'show_current'  		=> 'Tampilkan Saat Ini',
    'sign_in'				=> 'Masuk',
    'signature'             => 'Tanda tangan',
    'skin'       			=> 'Tema',
    'slack_test_msg'        => 'Oh hai! Looks like your Slack integration with Snipe-IT is working!',
    'some_features_disabled' => 'DEMO MODE: Beberapa fitur dinonaktifkan untuk penginstalan ini.',
    'site_name'				=> 'Nama Situs',
    'state'  				=> 'Negara',
    'status_labels'			=> 'Status Labels',
    'status'    			=> 'Status',
    'supplier'              => 'Pemasok',
    'suppliers'  			=> 'Pemasok',
    'sure_to_delete'    => 'Apakah anda yakin ingin menghapus',
    'submit'				=> 'Kirim',
    'target'                => 'Target',
    'time_and_date_display' => 'Tampilan Waktu dan Tanggal',
    'total_assets'			=> 'total aset',
    'total_licenses'		=> 'total lisensi',
    'total_accessories'		=> 'total aksesoris',
    'total_consumables'		=> 'total masa pakai',
    'type'  				=> 'Jenis',
    'undeployable'			=> 'Tidak dapat disebarkan',
    'unknown_admin'			=> 'Admin tidak diketahui',
    'username_format'		=> 'Format nama pengguna',
    'update'                => 'Perbarui',
    'upload_filetypes_help'      => 'Allowed filetypes are png, gif, jpg, jpeg, doc, docx, pdf, xls, xlsx, txt, lic, xml, zip, rtf and rar. Max upload size allowed is :size.',
    'uploaded'              => 'Unggah',
    'user'					=> 'Pengguna',
    'accepted'			    => 'diterima',
    'declined'			    => 'menurun',
    'unaccepted_asset_report' => 'Aset tidak diterima',
    'users'                 => 'Pengguna',
    'viewall'				=> 'View All',
    'viewassets'  			=> 'Lihat aset yang ditetapkan',
    'website'               => 'Situs Web',
    'welcome'				=> 'Selamat datang :nama',
    'years'					=> 'tahun',
    'yes' 					=> 'Yes',
    'zip'  					=> 'Zip',
    'noimage'				=> 'Gambar tidak diunggah atau gambar tidak ditemukan.',
    'token_expired'         => 'Sesi formulir anda sudah berakhir. Silahkan coba lagi.',
    'login_enabled'         => 'Login Enabled',
    'audit_due'             => 'Due for Audit',
    'audit_overdue'         => 'Overdue for Audit',
    'accept'                => 'Accept :asset',
    'i_accept'              => 'I accept',
    'i_decline'             => 'I decline',
    'sign_tos'              => 'Sign below to indicate that you agree to the terms of service:',
    'clear_signature'       => 'Clear Signature',
    'show_help'             => 'Show help',
    'hide_help'             => 'Hide help',
    ];

==> snipe-it-5.4.3.zip: snipe-it-5.4.3/resources/lang/en-ID/general.php <==
<?php

    return [
    'accessories'			=> 'Aksesoris',
    'activated'			    => 'Diaktifkan',
    'accessory'				=> 'Aksesoris',
    'accessory_report'		=> 'Laporan Aksesori',
    'action'                => 'Langkah',
    'activity_report'		=> 'Laporan Aktifitas',
    'address'				=> 'Alamat',
    'admin'					=> 'Admin',
    'administrator'			=> 'Administrator',
    'add_seats'             => 'Seat ditambahkan',
    'all_assets'			=> 'Semua aset',
    'all'       			=> 'Semua',
    'archived'              => 'Diarsipkan',
    'asset_models'			=> 'Model aset',
    'asset_model'			=> 'Model',
    'asset'					=> 'Aset',
    'asset_report'          => 'Laporan aset',
    'asset_tag'				=> 'Penanda aset',
    'asset_tags'            => 'Asset Tags',
    'assets_available'		=> 'Assets available',
    'accept_assets'         => 'Accept Assets :name',
    'accept_assets_menu'    => 'Accept Assets',
    'audit'				    => 'Audit',
    'audit_report'			=> 'Audit Log',
    'assets'				=> 'Aset',
    'avatar_delete'         => 'Hapus Avatar',
    'avatar_upload'         => 'Unggah Avatar',
    'back'      			=> 'Kembali',
    'bad_data'      		=> 'Tidak ada yang ditemukan. Mungkinkah data buruk?',
    'bulkaudit'             => 'Bulk Audit',
    'bulkaudit_status'      => 'Status Audit',
    'bulk_checkout'  		=> 'Periksa Bulk',
    'bulk_edit'             => 'Bulk Edit',
    'bulk_delete'           => 'Bulk Delete',
    'bulk_actions'          => 'Bulk Actions',
    'bulk_checkin_delete'   => 'Bulk Checkin &amp; Delete',
    'bystatus'              => 'by Status',
    'cancel'  				=> 'Batal',
    'categories'			=> 'Kategori',
    'category'				=> 'Kategori',
    'change' 		        => 'Masuk/keluar',
    'changeemail'  			=> 'Ubah alamat surel',
    'changepassword'  		=> 'Ubah kata sandi',
    'checkin'  				=> 'Mendaftar',
    'checkin_from'  		=> 'Checkin dari',
    'checkout'  			=> 'Checkout',
    'checkouts_count'       => 'Keluar',
    'checkins_count'        => 'Masuk',
    'user_requests_count'   => 'Permintaan',
    'city'  				=> 'Kota',
    'click_here'			=> 'Klik disini',
    'clear_selection'		=> 'Hapus yang dipilih',
    'companies'			    => 'Perusahaan',
    'company'				=> 'Perusahaan',
    'component'			    => 'Komponen',
    'components'			=> 'Komponen',
    'complete'				=> 'Lengkap',
    'consumable'			=> 'Dapat dikonsumsi',
    'consumables'			=> 'Dapat dikonsumsi',
    'country'  				=> 'Negara',
    'create'				=> 'Buat baru',
    'created'               => 'Item telah dibuat',
    'created_asset'			=> 'buat aset',
    'created_at' 			=> 'Dibuat di',
    'record_created' 		=> 'Record Created',
    'updated_at' 			=> 'Diperbarui pada',
    'currency'  			=> 'IDR', // this is deprecated
    'current'  				=> 'Saat ini',
    'current_password'      => 'Current Password',
    'customize_report'      => 'Customize Report',
    'custom_report'         => 'Laporan aset kostum',
    'dashboard'				=> 'Dashboard',
    'days'      			=> 'hari',
    'days_to_next_audit'    => 'Hari untuk audit selanjutnya',
    'date'					=> 'Tanggal',
    'debug_warning'         => 'Peringatan!',
    'debug_warning_text'    => 'Aplikasi ini berjalan dalam mode produksi dengan debugging diaktifkan. Hal ini dapat mengekspos data sensitif jika aplikasi Anda dapat diakses oleh dunia luar. Nonaktifkan mode debug dengan menetapkan nilai <code>APP_DEBUG</code> value in your <code>.env</code> file to <code>false</code>.',
    'delete'  				=> 'Hapus',
    'delete_confirm'  		=> 'Apa Anda yakin untuk menghapus :item?',
    'deleted'  				=> 'Dihapus',
    'delete_seats'  		=> 'Tempat dihapus',
    'deletion_failed'       => 'Deletion failed',
    'departments'           => 'Departemen',
    'department'            => 'Departemen',
    'deployed'				=> 'Diterapkan',
    'depreciation'			=> 'Penurunan nilai',
    'depreciations'         => 'Depreciations',
    'depreciation_report'	=> 'Laporan Penurunan',
    'details'               => 'Detail',
    'download'				=> 'Unduh',
    'download_all'		    => 'Download All',
    'editprofile'  			=> 'Sunting profil anda',
    'eol'					=> 'EOL',
    'email_domain'			=> 'Email Domain',
    'email_format'			=> 'Format Surel',
    'employee_number'       => 'Employee Number',
    'email_domain_help'		=> 'Ini digunakan untuk menghasilkan alamat surel ketika saat mengimpor',
    'error'				    => 'Error',
    'filastname_format'			=> 'Nama Depan Nama Belakang (jane.smith@example.com)',
    'firstname_lastname_format'	=> 'Nama Depan Nama Belakang (jane.smith@example.com)',
    'firstname_lastname_underscore_format' => 'Nama Depan Nama Belakang (jane.smith@example.com)',
    'lastnamefirstinitial_format' =>  'Nama Depan First Initial (smithj@example.com)',
    'firstintial_dot_lastname_format' => 'First Initial Last Name (j.smith@example.com)',
    'first'					=> 'Pertama',
    'firstnamelastname'     => 'First Name Last Name (janesmith@example.com)',
    'lastname_firstinitial' => 'Last Name First Initial (smith_j@example.com)',
    'firstinitial.lastname' => 'First Initial Last Name (j.smith@example.com)',
    'firstnamelastinitial'  => 'First Name Last Initial (janes@example.com)',
    'first_name'			=> 'Nama Pertama',
    'first_name_format'		=> 'Nama Depan (jane@example.com)',
    'files'                 => 'Berkas',
    'file_name'				=> 'Berkas',
    'file_type'             => 'File Type',
    'file_uploads'			=> 'Unggah berkas',
    'file_upload'           => 'File Upload',
    'generate'				=> 'Hasilkan',
    'generate_labels'       => 'Generate Labels',
    'github_markdown'      => 'Bidang ini mengizinkan penggunaan <a href="https://help.github.com/articles/github-flavored-markdown/">kode markup milik Github</a>.',
    'groups'				=> 'Kelompok',
    'gravatar_email'        => 'Alamat Email Gravatar',
    'gravatar_url'          => '<a href="http://gravatar.com"><small>Change your avatar at Gravatar.com</small></a>.',
    'history'  			    => 'Riwayat',
    'history_for'  			=> 'Riwayat untuk',
    'id'  					=> 'ID',
    'image'                 => 'Gambar',
    'image_delete'         	=> 'Hapus Gambar',
    'image_upload'         	=> 'Unggah Gambar',
    'filetypes_accepted_help'    => 'Accepted filetype is :types. Max upload size allowed is :size.|Accepted filetypes are :types. Max upload size allowed is :size.',
    'filetypes_size_help'   => 'Max upload size allowed is :size.',
    'image_filetypes_help'  => 'Accepted filetypes are jpg, webp, png, gif, and svg. Max upload size allowed is :size.',
    'import'         	    => 'Impor',
    'importing'         	=> 'Importing',
    'importing_help'        => 'You can import assets, accessories, licenses, components, consumables, and users via CSV file. <br><br>The CSV should be comma-delimited and formatted with headers that match the ones in the <a href="https://snipe-it.readme.io/docs/importing" target="_new">sample CSVs in the documentation</a>.',
    'import-history'        => 'Riwayat Impor',
    'asset_maintenance'        => 'Pemeliharaan Aset',
    'asset_maintenance_report' => 'Laporan Pemeliharaan Aset',
    'asset_maintenances'       => 'Pemeliharaan Aset',
    'item'  				=> 'Item',
    'item_name'             => 'Item Name',
    'insufficient_permissions' => 'Tidak ada hak akses!',
    'kits'       			=> 'Predefined Kits',
    'language'				=> 'Bahasa',
    'last'					=> 'Terakhir',
    'last_login'            => 'Login terakhir',
    'last_name'             => 'Nama Belakang',
    'license'				=> 'Lisensi',
    'license_report'        => 'Laporan Lisensi',
    'licenses_available'	=> 'lisensi yang tersedia',
    'licenses'				=> 'Lisensi',
    'list_all'				=> 'Tampilkan semua',
    'loading'				=> 'Loading... please wait....',
    'lock_passwords'        => 'This field value will not be saved in a demo installation.',
    'feature_disabled'      => 'Fitur ini telah dinonaktifkan untuk instalasi demo.',
    'location'              => 'Lokasi',
    'locations'				=> 'Lokasi',
    'logo_size'				=> 'Square logos look best with Logo + Text. Logo maximum display size is 50px high x 500px wide.  ',
    'logout'				=> 'Keluar',
    'lookup_by_tag'     => 'Mencari berdasarkan tag aset',
    'maintenances'          => 'Pemeliharaan',
    'manage_api_keys'       => 'Manage API Keys',
    'manufacturer'			=> 'Pabrikan',
    'manufacturers'			=> 'Pabrikan',
    'markdown'				=> 'Bidang ini mengizinkan penggunaan <a href="https://help.github.com/articles/github-flavored-markdown/">kode markup milik Github</a>.',
    'min_amt'				=> 'Jml Min.',
    'min_amt_help'          => 'Minimum number of items that should be available before an alert gets triggered. Leave Min. QTY blank if you do not want to receive alerts for low inventory.',
    'model_no'				=> 'No. Model',
    'months'				=> 'bulan',
    'moreinfo'				=> 'Info Lengkap',
    'name'					=> 'Nama',
    'new_password'          => 'New Password',
    'next'					=> 'Selanjutnya',
    'next_audit_date'		=> 'Tanggal Audit berikutnya',
    'last_audit'		    => 'Audit Terakhir',
    'new'					=> 'baru!',
    'no_depreciation'		=> 'Tidak ada penyusutan',
    'no_results'			=> 'Tidak ada Hasil.',
    'no'  					=> 'Tidak',
    'notes'  				=> 'Catatan',
    'order_number'          => 'Nomor Pemesanan',
    'page_menu'				=> 'Menampilkan item _MENU_',
    'pagination_info'		=> 'Menampilkan item _START_ to _END_ of _TOTAL_',
    'pending'				=> 'Tertunda',
    'people'				=> 'Orang',
    'per_page'				=> 'Hasil per Halaman',
    'previous'				=> 'Sebelumnya',
    'processing'			=> 'Memproses',
    'profile'				=> 'Profil anda',
    'purchase_cost'                              => 'Harga pembelian',
    'purchase_date'         => 'Tanggal Pembelian',
    'qty'		            => 'JML',
    'quantity'		        => 'Jumlah',
    'quantity_minimum'      => 'You have :count items below or almost below minimum quantity levels',
    'quickscan_checkin'  	=> 'Quick Scan Checkin',
    'quickscan_checkin_status'  	=> 'Checkin Status',
    'ready_to_deploy'		=> 'Siap digunakan',
    'recent_activity'		=> 'Aktifitas tebaru',
    'remaining'             => 'Remaining',
    'remove_company'        => 'Hapus Asosiasi Perusahaan',
    'reports'				=> 'Laporan',
    'restored'				=> 'dikembalikan',
    'restore'				=> 'Restore',
    'requestable_models'    => 'Requestable Models',
    'requested'				=> 'Diminta',
    'requested_date'        => 'Requested Date',
    'requested_assets'      => 'Requested Assets',
    'requested_assets_menu' => 'Requested Assets',
    'request_canceled'      => 'Permintaan dibatalkan',
    'save'  				=> 'Simpan',
    'select'				=> 'Pilih',
    'select_all'            => 'Select All',
    'search'				=> 'Cari',
    'select_category'       => 'Pilih kategori',
    'select_department'     => 'Pilih Departemen',
    'select_depreciation'	=> 'Pilih Jenis Penyusutan',
    'select_location'		=> 'Pilih lokasi',
    'select_manufacturer'	=> 'Pilih Produsen',
    'select_model'			=> 'Pilih sebuah model',
    'select_supplier'		=> 'Pilih pabrikan',
    'select_user'			=> 'Pilih pengguna',
    'select_date'			=> 'Pilih tanggal (YYYY-MM-DD)',
    'select_statuslabel'	=> 'Pilih status',
    'select_company'    	=> 'Pilih perusahaan',
    'select_asset'    		=> 'Pilih aset',
    'settings'				=> 'Pengaturan',
    'show_deleted'  		=> 'Tampilkan yang Dihapus',
    'show_current'  		=> 'Tampilkan Saat Ini',
    'sign_in'				=> 'Masuk',
    'signature'             => 'Tanda tangan',
    'skin'       			=> 'Tema',
    'slack_msg_note'        => 'A slack message will be sent',
    'slack_test_msg'        => 'Oh hai! Looks like your Slack integration with Snipe-IT is working!',
    'some_features_disabled' => 'DEMO MODE: Beberapa fitur dinonaktifkan untuk penginstalan ini.',
    'site_name'				=> 'Nama Situs',
    'state'  				=> 'Negara',
    'status_labels'			=> 'Status Labels',
    'status'    			=> 'Status',
    'supplier'              => 'Pemasok',
    'suppliers'  			=> 'Pemasok',
    'sure_to_delete'    => 'Apakah anda yakin ingin menghapus',
    'submit'				=> 'Kirim',
    'target'                => 'Target',
    'toggle_navigation'     => 'Toogle Navigation',
    'time_and_date_display' => 'Tampilan Waktu dan Tanggal',
    'total_assets'			=> 'total aset',
    'total_licenses'		=> 'total lisensi',
    'total_accessories'		=> 'total aksesoris',
    'total_consumables'		=> 'total masa pakai',
    'type'  				=> 'Jenis',
    'undeployable'			=> 'Tidak dapat disebarkan',
    'unknown_admin'			=> 'Admin tidak diketahui',
    'username_format'		=> 'Format nama pengguna',
    'update'                => 'Perbarui',
    'upload_filetypes_help'      => 'Allowed filetypes are png, gif, jpg, jpeg, doc, docx, pdf, xls, xlsx, txt, lic, xml, zip, rtf and rar. Max upload size allowed is :size.',
    'uploaded'              => 'Unggah',
    'user'					=> 'Pengguna',
    'accepted'			    => 'diterima',
    'declined'			    => 'menurun',
    'unaccepted_asset_report' => 'Aset tidak diterima',
    'users'                 => 'Pengguna',
    'viewall'				=> 'View All',
    'viewassets'  			=> 'Lihat aset yang ditetapkan',
    'viewassetsfor'         => 'View Assets for :name',
    'website'               => 'Situs Web',
    'welcome'				=> 'Selamat datang :nama',
    'years'					=> 'tahun',
    'yes' 					=> 'Yes',
    'zip'  					=> 'Zip',
    'noimage'				=> 'Gambar tidak diunggah atau gambar tidak ditemukan.',
    'token_expired'         => 'Sesi formulir anda sudah berakhir. Silahkan coba lagi.',
    'login_enabled'         => 'Login Enabled',
    'audit_due'             => 'Due for Audit',
    'audit_overdue'         => 'Overdue for Audit',
    'accept'                => 'Accept :asset',
    'i_accept'              => 'I accept',
    'i_decline'             => 'I decline',
    'accept_decline'        => 'Accept/Decline',
    'sign_tos'              => 'Sign below to indicate that you agree to the terms of service:',
    'clear_signature'       => 'Clear Signature',
    'show_help'             => 'Show help',
    'hide_help'             => 'Hide help',
    'view_all'              => 'view all',
    'hide_deleted'          => 'Hide Deleted',
    'email'                 => 'Email',
    'do_not_change'         => 'Do Not Change',
    'bug_report'            => 'Report a Bug',
    'user_manual'           => 'User\'s Manual',
    'setup_step_1'          => 'Step 1',
    'setup_step_2'          => 'Step 2',
    'setup_step_3'          => 'Step 3',
    'setup_step_4'          => 'Step 4',
    'setup_config_check'    => 'Configuration Check',
    'setup_create_database' => 'Create Database Tables',
    'setup_create_admin'    => 'Create Admin User',
    'setup_done'            => 'Finished!',
    'bulk_edit_about_to'    => 'You are about to edit the following: ',
    'checked_out'           => 'Checked Out',
    'checked_out_to'        => 'Checked out to',
    'fields'                => 'Fields',
    'last_checkout'         => 'Last Checkout',
    'due_to_checkin'        => 'The following :count items are due to be checked in soon:',
    'expected_checkin'      => 'Expected Checkin',
    'reminder_checked_out_items' => 'This is a reminder of the items currently checked out to you. If you feel this list is inaccurate (something is missing, or something appears here that you believe you never received), please email :reply_to_name at :reply_to_address.',
    'changed'               => 'Changed',
    'to'                    => 'To',
    'report_fields_info'    => '<p>Select the fields you would like to include in your custom report, and click Generate. The file (custom-asset-report-YYYY-mm-dd.csv) will download automatically, and you can open it in Excel.</p>
            <p>If you would like to export only certain assets, use the options below to fine-tune your results.</p>',
    'range'                 => 'Range',
    'bom_remark'            => 'Add a BOM (byte-order mark) to this CSV',
    'improvements'          => 'Improvements',
    'information'           => 'Information',
    'permissions'           => 'Permissions',
    'managed_ldap'          => '(Managed via LDAP)',
    'export'                => 'Export',
    'ldap_sync'             => 'LDAP Sync',
    'ldap_user_sync'        => 'LDAP User Sync',
    'synchronize'           => 'Synchronize',
    'sync_results'          => 'Synchronization Results',
    'license_serial'        => 'Serial/Product Key',
    'invalid_category'      => 'Invalid category',
    'dashboard_info'        => 'This is your dashboard. There are many like it, but this one is yours.',
    '60_percent_warning'    => '60% Complete (warning)',
    'dashboard_empty'       => 'It looks like you haven not added anything yet, so we do not have anything awesome to display. Get started by adding some assets, accessories, consumables, or licenses now!',
    'new_asset'             => 'New Asset',
    'new_license'           => 'New License',
    'new_accessory'         => 'New Accessory',
    'new_consumable'        => 'New Consumable',
    'collapse'              => 'Collapse',
    'assigned'              => 'Assigned',
    'asset_count'           => 'Asset Count',
    'accessories_count'     => 'Accessories Count',
    'consumables_count'     => 'Consumables Count',
    'components_count'      => 'Components Count',
    'licenses_count'        => 'Licenses Count',
    'notification_error'    => 'Error:',
    'notification_error_hint' => 'Please check the form below for errors',
    'notification_success'  => 'Success:',
    'notification_warning'   => 'Warning:',
    'notification_info'      => 'Info:',
    'asset_information'     => 'Asset Information',
    'model_name'            => 'Model Name:',
    'asset_name'            => 'Asset Name:',
    'consumable_information' => 'Consumable Information:',
    'consumable_name'       => 'Consumable Name:',
    'accessory_information' => 'Accessory Information:',
    'accessory_name'       => 'Accessory Name:',
    'clone_item'            => 'Clone Item',
    'checkout_tooltip' => 'Check this item out',
    'checkin_tooltip' => 'Check this item in',
    'checkout_user_tooltip' => 'Check this item out to a user',
];
